/**
 * @file        应用主入口，初始化Elysia实例
 * @author      hotok
 * @date        2025-06-28
 * @lastEditor  hotok
 * @lastEditTime 2025-06-28
 * @description Elysia API服务应用入口文件，集成Winston日志系统
 */

import { Elysia } from 'elysia';
import { swaggerPlugin } from '@/plugins/swagger.plugins';
import { authController } from '@/controllers/try/auth.controller';
import { protectedController } from '@/controllers/try/protected.controller';
import { healthController } from '@/controllers/health.controller';
import * as config from '@/config/logger.config';
import loggerPlugin from '@/plugins/logger.plugins';
import { errorHandlerPlugin } from '@/plugins/errorHandler.plugins';
class AuthenticationError extends Error {
    constructor(message: string, code = 500) {
        super(message);
        this.name = 'AuthenticationError';
        if (code === 401) {
            this.name = 'Unauthorized';
        }
    }
}
/**
 * Elysia应用实例
 * @type {Elysia}
 */
export const app = new Elysia()
    .state('config', config)
    .use(loggerPlugin)
    .use(errorHandlerPlugin)
    .use(swaggerPlugin)
    .use(authController)
    .use(protectedController)
    .use(healthController)
    .state('counter', 0) // 定义名为 counter 的初始值

    // 批量定义  不会覆盖前面单独定义的
    .state({
        version: '1.0',
        server: 'Bun',
    })
    .state('Error', (message: string) => {
        console.log('message', message);
        return new AuthenticationError(message);
    })
    .state('db', '一个方法')
    .decorate('closeDB', () => console.log('关闭方法')); // 添加关闭方法


// app.closeDB() 可以以在路由中调用
