/**
 * @file        JWT插件封装
 * @author      hotok
 * @date        2025-06-28
 * @lastEditor  hotok
 * @lastEditTime 2025-06-28
 * @description 封装Elysia JWT插件，统一配置密钥
 */
import { Elysia } from 'elysia';
import { jwt } from '@elysiajs/jwt';
import { jwtConfig } from '@/config/jwt.config';

export const jwtPlugin = jwt({
    name: 'jwt',
    secret: jwtConfig.secret,
    exp: jwtConfig.exp,
});

export const jwtAuthPlugin = (app: Elysia) =>
    app
        .use(jwtPlugin)
        .derive(async ({ jwt, headers, status }) => {
            const authHeader = headers['authorization'];
            if (!authHeader?.startsWith('Bearer ')) {
                return status(401, '未携带Token');
            }
            const token = authHeader.replace('Bearer ', '');
            try {
                const user = await jwt.verify(token);
                if (!user) return status(401, 'Token无效');
                return { user };
            } catch {
                return {};
            }
        })
        .onBeforeHandle(({ user, status }) => {
            if (!user) {
                return status(401, '未授权');
            }
        });
